aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/editgroup.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/editgroup.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/editgroup.py35
1 files changed, 15 insertions, 20 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/editgroup.py b/python_openapi_client/fatcat_openapi_client/models/editgroup.py
index 37e0628a..37742d90 100644
--- a/python_openapi_client/fatcat_openapi_client/models/editgroup.py
+++ b/python_openapi_client/fatcat_openapi_client/models/editgroup.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -16,25 +16,22 @@ import re # noqa: F401
import six
-from fatcat_openapi_client.models.editgroup_annotation import EditgroupAnnotation # noqa: F401,E501
-from fatcat_openapi_client.models.editgroup_edits import EditgroupEdits # noqa: F401,E501
-from fatcat_openapi_client.models.editor import Editor # noqa: F401,E501
-
class Editgroup(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'editgroup_id': 'str',
'editor_id': 'str',
'editor': 'Editor',
@@ -42,7 +39,7 @@ class Editgroup(object):
'created': 'datetime',
'submitted': 'datetime',
'description': 'str',
- 'extra': 'object',
+ 'extra': 'dict(str, object)',
'annotations': 'list[EditgroupAnnotation]',
'edits': 'EditgroupEdits'
}
@@ -61,7 +58,7 @@ class Editgroup(object):
}
def __init__(self, editgroup_id=None, editor_id=None, editor=None, changelog_index=None, created=None, submitted=None, description=None, extra=None, annotations=None, edits=None): # noqa: E501
- """Editgroup - a model defined in Swagger""" # noqa: E501
+ """Editgroup - a model defined in OpenAPI""" # noqa: E501
self._editgroup_id = None
self._editor_id = None
@@ -120,8 +117,8 @@ class Editgroup(object):
raise ValueError("Invalid value for `editgroup_id`, length must be less than or equal to `26`") # noqa: E501
if editgroup_id is not None and len(editgroup_id) < 26:
raise ValueError("Invalid value for `editgroup_id`, length must be greater than or equal to `26`") # noqa: E501
- if editgroup_id is not None and not re.search('[a-zA-Z2-7]{26}', editgroup_id): # noqa: E501
- raise ValueError("Invalid value for `editgroup_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
+ if editgroup_id is not None and not re.search(r'[a-zA-Z2-7]{26}', editgroup_id): # noqa: E501
+ raise ValueError(r"Invalid value for `editgroup_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
self._editgroup_id = editgroup_id
@@ -149,8 +146,8 @@ class Editgroup(object):
raise ValueError("Invalid value for `editor_id`, length must be less than or equal to `26`") # noqa: E501
if editor_id is not None and len(editor_id) < 26:
raise ValueError("Invalid value for `editor_id`, length must be greater than or equal to `26`") # noqa: E501
- if editor_id is not None and not re.search('[a-zA-Z2-7]{26}', editor_id): # noqa: E501
- raise ValueError("Invalid value for `editor_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
+ if editor_id is not None and not re.search(r'[a-zA-Z2-7]{26}', editor_id): # noqa: E501
+ raise ValueError(r"Invalid value for `editor_id`, must be a follow pattern or equal to `/[a-zA-Z2-7]{26}/`") # noqa: E501
self._editor_id = editor_id
@@ -158,7 +155,6 @@ class Editgroup(object):
def editor(self):
"""Gets the editor of this Editgroup. # noqa: E501
- Complete editor object identified by `container_id` field. Only included in GET responses. # noqa: E501
:return: The editor of this Editgroup. # noqa: E501
:rtype: Editor
@@ -169,7 +165,6 @@ class Editgroup(object):
def editor(self, editor):
"""Sets the editor of this Editgroup.
- Complete editor object identified by `container_id` field. Only included in GET responses. # noqa: E501
:param editor: The editor of this Editgroup. # noqa: E501
:type: Editor
@@ -276,7 +271,7 @@ class Editgroup(object):
Free-form JSON metadata attached to this editgroup. Eg, metadata provenance, or script user-agent details. See guide for (unenforced) schema norms. # noqa: E501
:return: The extra of this Editgroup. # noqa: E501
- :rtype: object
+ :rtype: dict(str, object)
"""
return self._extra
@@ -287,7 +282,7 @@ class Editgroup(object):
Free-form JSON metadata attached to this editgroup. Eg, metadata provenance, or script user-agent details. See guide for (unenforced) schema norms. # noqa: E501
:param extra: The extra of this Editgroup. # noqa: E501
- :type: object
+ :type: dict(str, object)
"""
self._extra = extra
@@ -340,7 +335,7 @@ class Editgroup(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -16,25 +16,22 @@ import re # noqa: F401
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name